@@ -2,9 +2,11 @@
 
 import configparser
 import os
+from pathlib import Path
+
 from prompt_toolkit import prompt
 from prompt_toolkit.completion import FuzzyWordCompleter
-from pathlib import Path
+from prompt_toolkit.validation import Validator
 
 REGIONS = [
     "eu-north-1",
@@ -25,10 +27,12 @@ REGIONS = [
     "us-west-2"
 ]
 
+AWS_VARS = ["AWS_SECRET_ACCESS_KEY", "AWS_ACCESS_KEY_ID", "AWS_SESSION_TOKEN", "AWS_SECURITY_TOKEN"]
 
-class ARS():
 
-    def init(self):
+class ARS:
+
+    def __init__(self):
         self.config = configparser.ConfigParser()
         default_path = os.path.join(Path.home(), '.aws/credentials')
         extended_path = os.environ.get('AWS_PROFILE_SWITCHER_PATH')
@@ -39,48 +43,51 @@ class ARS():
         self.config.read(path)
 
     def run(self, sys_args):
+        self.__init__()
         profile_arg, region_arg = self.parse_arguments(sys_args)
-        self.init()
-        profile = self.prompt_for_profile_name(profile_arg)
-        if profile:
-            self.set_aws_environment_variables(profile)
+        self.set_aws_vars(profile_arg)
         if not os.environ.get("AWS_DEFAULT_REGION"):
             self.set_aws_region(region_arg)
 
-    def parse_arguments(self, sys_args):
+    def set_aws_vars(self, arg):
+        validator = Validator.from_callable(
+            self.profile_validator,
+            error_message='Not a valid profile name',
+            move_cursor_to_end=True)
+        profile = prompt('Enter Profile: ',
+                         default=arg,
+                         completer=FuzzyWordCompleter(self.config.sections()),
+                         complete_while_typing=True,
+                         validator=validator)
+
+        for k, v in self.config[profile].items():
+            if k.upper() in AWS_VARS:
+                print(f"export {k.upper()}={v}")
+
+    def profile_validator(self, text):
+        if text in self.config.sections():
+            return True
+        else:
+            return False
+
+    @staticmethod
+    def set_aws_region(arg):
+        region = prompt('AWS_DEFAULT_REGION Not Set. Choose Region: ', default=arg,
+                        completer=FuzzyWordCompleter(REGIONS))
+        print(f"export AWS_DEFAULT_REGION={region}")
+
+    @staticmethod
+    def region_validator(text):
+        if text in REGIONS:
+            return True
+        else:
+            return False
+
+    @staticmethod
+    def parse_arguments(sys_args):
         if len(sys_args) <= 1:
             return "", ""
         elif len(sys_args) == 2:
             return sys_args[1], ""
         else:
             return sys_args[1], sys_args[2]
-
-
-    def set_aws_environment_variables(self, profile):
-        variables = ["AWS_SECRET_ACCESS_KEY", "AWS_ACCESS_KEY_ID", "AWS_SESSION_TOKEN", "AWS_SECURITY_TOKEN"]
-        for k, v in self.config[profile].items():
-            if k.upper() in variables:
-                print(f"export {k.upper()}={v}")
-
-
-    def set_aws_region(self, arg):
-        region = prompt('AWS_DEFAULT_REGION Not Set. Choose Region: ', default=arg, completer=FuzzyWordCompleter(REGIONS))
-        if self.validate(region, REGIONS):
-            print(f"export AWS_DEFAULT_REGION={region}")
-
-    def validate(self, raw, expected):
-        if raw in expected:
-            return True
-        else:
-            raise Exception(f"{raw} is not valid, must be one of {expected}")
-
-    def prompt_for_profile_name(self, arg):
-        res = None
-        profile = prompt('Enter Profile: ', default=arg, completer=FuzzyWordCompleter(self.config.sections()),
-                         complete_while_typing=True)
-        if self.validate(profile, self.config.sections()):
-            res = profile
-        return res
-
-
-
